@@ -13,7 +13,7 @@ pub(super) const EXCHANGE_NAME: &str = "binance";
 
 pub(super) const WEBSOCKET_URL: &str = "wss://stream.opsnest.com/stream";
 
-const PING_INTERVAL_AND_MSG: (u64, &str) = (240, r#"{"event":"ping"}"#);
+const CLIENT_PING_INTERVAL_AND_MSG: (u64, &str) = (240, r#"{"event":"ping"}"#);
 
 /// Binance Option market
 ///
@@ -86,7 +86,8 @@ define_client!(
     WEBSOCKET_URL,
     channels_to_commands,
     on_misc_msg,
-    Some(PING_INTERVAL_AND_MSG)
+    Some(CLIENT_PING_INTERVAL_AND_MSG),
+    None
 );
 
 fn to_raw_channel(channel: &str, pair: &str) -> String {
