@@ -14,7 +14,7 @@ pub(super) const EXCHANGE_NAME: &str = "bitmex";
 
 const WEBSOCKET_URL: &str = "wss://www.bitmex.com/realtime";
 
-const PING_INTERVAL_AND_MSG: (u64, &str) = (5, "ping");
+const CLIENT_PING_INTERVAL_AND_MSG: (u64, &str) = (5, "ping");
 
 /// The WebSocket client for BitMEX.
 ///
@@ -134,7 +134,8 @@ define_client!(
     WEBSOCKET_URL,
     channels_to_commands,
     on_misc_msg,
-    Some(PING_INTERVAL_AND_MSG)
+    Some(CLIENT_PING_INTERVAL_AND_MSG),
+    None
 );
 
 #[cfg(test)]
