@@ -12,7 +12,7 @@ pub(super) const EXCHANGE_NAME: &str = "okex";
 
 const WEBSOCKET_URL: &str = "wss://real.okex.com:8443/ws/v3";
 
-const PING_INTERVAL_AND_MSG: (u64, &str) = (30, "ping");
+const CLIENT_PING_INTERVAL_AND_MSG: (u64, &str) = (30, "ping");
 
 /// The WebSocket client for OKEx.
 ///
@@ -158,7 +158,8 @@ define_client!(
     WEBSOCKET_URL,
     channels_to_commands,
     on_misc_msg,
-    Some(PING_INTERVAL_AND_MSG)
+    Some(CLIENT_PING_INTERVAL_AND_MSG),
+    None
 );
 
 #[cfg(test)]
